local AssignSoldier = ...

AssignSoldier:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")

AssignSoldier:register({
        DataType = "BUILDING_FUNCTION_TRAINING_GROUND",
        Id = _assignSoldierPrefix .. "_FUNCTION",
        WorkerCapacity = 1,
        RelatedJob = { Job = "SOLDIER", Behavior = _assignSoldierPrefix .. "_BEHAVIOR_TREE" },
        TrainingBehaviorList = { _assignSoldierPrefix .. "_BEHAVIOR_TREE" },
        VillagerProfile = "PROFILE_SOLDIER"
})

-- Apply building asset processor
AssignSoldier:registerAssetProcessor("models/keepTrap.fbx", {
    DataType = "BUILDING_ASSET_PROCESSOR"
})
AssignSoldier:registerAssetProcessor("models/smallGate.fbx", {
    DataType = "BUILDING_ASSET_PROCESSOR"
})

function registerAEnd(_nameFbxFile, _nameFbx, _nameAsset, _workplaceCustom, _isVisibleWhenBuilt)
    -- Register Main prefab nodes
    AssignSoldier:registerAssetId("models/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameFbx .. "Part", _assignSoldierPrefix .. "_" .. _nameAsset .. "_PREFAB")

    -- Register the building part
    AssignSoldier:register({
	DataType = "BUILDING_PART",
	Id = _assignSoldierPrefix .. "_" .. _nameAsset .. "_PART",
	Name = _assignSoldierPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = _assignSoldierPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _assignSoldierPrefix .. "_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 0 }
		}
	},
        IsVisibleWhenBuilt = _isVisibleWhenBuilt,
        AssetBuildingFunction = _assignSoldierPrefix .. "_FUNCTION"
    })
    AssignSoldier:registerPrefabComponent("models/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameFbx .. "Part", {
        DataType = "ASSIGN_SOLDIER_PATH_AEND_COMP",
        Enabled = true,
        WorkplaceCustom = _workplaceCustom
    })
end

registerAEnd("keepTrap", "access/keepTrapAccess", "KEEP_TRAP_ACCESS", "KeepTrapAccess", false)
registerAEnd("smallGate", "access/smallGateAccessR", "SMALL_GATE_ACCESS_R", "KeepTrapAccess", false)
registerAEnd("smallGate", "access/smallGateAccessL", "SMALL_GATE_ACCESS_L", "KeepTrapAccess", false)

function registerKeepTrapPlatform(_nameFbxFile, _nameFbx)
    AssignSoldier:configurePrefabFlagList("models/" .. _nameFbxFile .. ".fbx/Prefab/access/" .. _nameFbx .. "Part", { "PLATFORM" })

    AssignSoldier:registerPrefabComponent("models/" .. _nameFbxFile .. ".fbx/Prefab/access/" .. _nameFbx .. "Part/KEEP_TRAP_ACCESS_GUARDING_LOCATION", {
            DataType = "ASSIGN_SOLDIER_ACCESS_GUARDING_LOCATION_COMP",
            Enabled = true
    })
    AssignSoldier:registerPrefabComponent("models/" .. _nameFbxFile .. ".fbx/Prefab/access/" .. _nameFbx .. "Part/KEEP_TRAP_ACCESS_INTERMEDIATE_LOCATION_UP", {
            DataType = "ASSIGN_SOLDIER_ACCESS_INTERMEDIATE_LOCATION_UP_COMP",
            Enabled = true
    })
    AssignSoldier:registerPrefabComponent("models/" .. _nameFbxFile .. ".fbx/Prefab/access/" .. _nameFbx .. "Part/KEEP_TRAP_ACCESS_INTERMEDIATE_LOCATION_DOWN", {
            DataType = "ASSIGN_SOLDIER_ACCESS_INTERMEDIATE_LOCATION_DOWN_COMP",
            Enabled = true
    })
    AssignSoldier:registerPrefabComponent("models/" .. _nameFbxFile .. ".fbx/Prefab/access/" .. _nameFbx .. "Part/KEEP_TRAP_ACCESS_INTERMEDIATE_LOCATION_OUT", {
            DataType = "ASSIGN_SOLDIER_ACCESS_INTERMEDIATE_LOCATION_OUT_COMP",
            Enabled = true
    })
end

registerKeepTrapPlatform("keepTrap", "keepTrapAccess")
registerKeepTrapPlatform("smallGate", "smallGateAccessR")
registerKeepTrapPlatform("smallGate", "smallGateAccessL")

